################################
Hybrid quantum algorithms
################################

Learn more about hybrid quantum algorithms.

.. toctree::
    :maxdepth: 2

**************************
`QAOA <https://github.com/aws/amazon-braket-examples/blob/main/examples/hybrid_quantum_algorithms/QAOA/QAOA_braket.ipynb>`_
**************************

This tutorial shows how to (approximately) solve binary combinatorial optimization problems 
using the Quantum Approximate Optimization Algorithm (QAOA). 

**************************
`VQE Transverse Ising <https://github.com/aws/amazon-braket-examples/blob/main/examples/hybrid_quantum_algorithms/VQE_Transverse_Ising/VQE_Transverse_Ising_Model.ipynb>`_
**************************

This tutorial shows how to solve for the ground state of the Transverse Ising Model
using the variational quantum eigenvalue solver (VQE). 

**************************
`VQE Chemistry <https://github.com/aws/amazon-braket-examples/blob/main/examples/hybrid_quantum_algorithms/VQE_Chemistry/VQE_chemistry_braket.ipynb>`_
**************************

This tutorial shows how to implement the Variational Quantum Eigensolver (VQE) algorithm in 
Amazon Braket SDK to compute the potential energy surface (PES) for the Hydrogen molecule. 